## 核心实现逻辑

实现思路：用户在代码中写两个 <trtc-remote-view /> 标签，分别对应两个不同的 viewId(eg. 大窗时的 viewId='remoteBigID', 小窗时的 viewId='remoteSmallID')，在不同时刻渲染对应的 view。

```html
	<view class="trtc-box">
		<view v-if="isLocalSmall" class="big-view">
			<trtc-remote-view class="big-view" :userId="remoteUserId" viewId="remoteBigID"></trtc-remote-view>
		</view>

		<view :class="[isLocalSmall ? 'small-view' : 'big-view']" >
			<trtc-local-view :class="[isLocalSmall ? 'small-view' : 'big-view']" :viewId="userId"></trtc-local-view>
		</view>

		<view v-if="!isLocalSmall" class="small-view">
			<trtc-remote-view class="small-view" :userId="remoteUserId" viewId="remoteSmallID"></trtc-remote-view>
		</view>
	</view>

	<button @click="toggleWindowSize"> toggleWindowSize </button>
	<button @click="() => startRemoteView('remoteBigID')">Start Remote View</button>
```

```javascript
toggleWindowSize() {
	this.isLocalSmall = !this.isLocalSmall;
	if (this.isLocalSmall) {
		this.startRemoteView('remoteBigID')
	} else {
		this.startRemoteView('remoteSmallID');
	}
},
```

```css
.trtc-box {
	width: 300px;
	height: 500px;
	border: 1px solid black;
	position: relative;
}

.big-view {
	width: 250px;
	height: 200px;
	position: absolute;
	background-color: red;
}

.small-view {
	width: 100px;
	height: 100px;
	position: absolute;
	right: 0;
	top: 0;
	background-color: green;
}
```

## 快速体验
1. 下载 [API-Example](https://cloud.tencent.com/document/product/647/72629)。
![alt text](./img/image.png)
2. 替换 `pages/example/1v1/index.nvue` 为当前目录的 `index.nvue`。
3. 替换 `common/trtc-nvue.css` 为当前目录的 `trtc-nvue.css`。